@@ -8,6 +8,7 @@
 # granted to it by virtue of its status as an Intergovernmental Organization  #
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
+from concurrent.futures import ThreadPoolExecutor
 import glob
 import os
 from os.path import dirname, join
@@ -95,7 +96,7 @@ def check_production(production_name):
 
 
 def create_output_dir(production_name):
-    """Function to create the output dir a test"""
+    """Create the directory structure for testing locally"""
 
     from datetime import datetime
 
@@ -132,3 +133,28 @@ def create_output_dir(production_name):
     os.symlink(os.getcwd(), fake_install_dir)
 
     return dynamic_dir, out_dir
+
+
+def log_popen_pipe(p, pipe_name):
+    result = b""
+    while p.poll() is None:
+        line = getattr(p, pipe_name).readline()
+        result += line
+        try:
+            line = line.decode().strip()
+        except UnicodeDecodeError:
+            line = repr(line)
+        click.echo(line)
+    return result
+
+
+def logging_subprocess_run(args, *, cwd=None):
+    with subprocess.Popen(
+        args, stdout=subprocess.PIPE, stderr=subprocess.PIPE, cwd=cwd
+    ) as p:
+        with ThreadPoolExecutor(2) as pool:
+            stdout = pool.submit(log_popen_pipe, p, "stdout")
+            stderr = pool.submit(log_popen_pipe, p, "stderr")
+            stdout = stdout.result()
+            stderr = stderr.result()
+    return subprocess.CompletedProcess(args, p.returncode, stdout, stderr)
